==> scalarx_2.10-0.2.3-JS.jar: rx/core/Var$.js <==
/** @constructor */
ScalaJS.c.rx_core_Var$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Var$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Var$.prototype.constructor = ScalaJS.c.rx_core_Var$;
ScalaJS.c.rx_core_Var$.prototype.apply__Lscala_Function0__T__Lrx_core_Var = (function(value, name) {
  return new ScalaJS.c.rx_core_Var().init___Lscala_Function0__T(value, name)
});
ScalaJS.c.rx_core_Var$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Var$.prototype.set__Lscala_collection_Seq__Lrx_core_Propagator__O = (function(thingies, evidence$3) {
  thingies.foreach__Lscala_Function1__V(new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(x$4) {
      x$4.commit__V();
      return ScalaJS.bV(undefined)
    })
  })()));
  return ScalaJS.modules.rx_core_Propagator().apply__Lrx_core_Propagator__Lrx_core_Propagator(evidence$3).propagate__Lscala_collection_immutable_Set__O(ScalaJS.as.scala_collection_TraversableOnce(thingies.flatMap__Lscala_Function1__Lscala_collection_generic_CanBuildFrom__O(new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(v) {
      return ScalaJS.as.scala_collection_immutable_Set(v.v__Lrx_core_Var().children__Lscala_collection_immutable_Set().map__Lscala_Function1__Lscala_collection_generic_CanBuildFrom__O(new ScalaJS.c.rx_core_Var$$anonfun$set$2$$anonfun$apply$1().init___Lrx_core_Var$$anonfun$set$2__Lrx_core_Staged(this, v), ScalaJS.modules.scala_collection_immutable_Set().canBuildFrom__Lscala_collection_generic_CanBuildFrom()))
    })
  })()), ScalaJS.modules.scala_collection_Seq().canBuildFrom__Lscala_collection_generic_CanBuildFrom())).toSet__Lscala_collection_immutable_Set())
});
ScalaJS.c.rx_core_Var$.prototype.$$lessinit$greater$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Var$.prototype.set__Lscala_collection_Seq__Lrx_core_Propagator__ = (function(thingies, evidence$3) {
  return this.set__Lscala_collection_Seq__Lrx_core_Propagator__O(thingies, evidence$3)
});
ScalaJS.c.rx_core_Var$.prototype.apply__Lscala_Function0__T__ = (function(value, name) {
  return this.apply__Lscala_Function0__T__Lrx_core_Var(value, name)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Var$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Var$.prototype = ScalaJS.c.rx_core_Var$.prototype;
ScalaJS.is.rx_core_Var$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Var$)))
});
ScalaJS.as.rx_core_Var$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Var$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Var")
  }
});
ScalaJS.isArrayOf.rx_core_Var$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Var$)))
});
ScalaJS.asArrayOf.rx_core_Var$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Var$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Var;", depth)
  }
});
ScalaJS.data.rx_core_Var$ = new ScalaJS.ClassTypeData({
  rx_core_Var$: 0
}, false, "rx.core.Var$", ScalaJS.data.java_lang_Object, {
  rx_core_Var$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Var$.prototype.$classData = ScalaJS.data.rx_core_Var$;
ScalaJS.moduleInstances.rx_core_Var = undefined;
ScalaJS.modules.rx_core_Var = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Var)) {
    ScalaJS.moduleInstances.rx_core_Var = new ScalaJS.c.rx_core_Var$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Var
});
//@ sourceMappingURL=Var$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/core/Var$.js <==
/** @constructor */
ScalaJS.c.rx_core_Var$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Var$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Var$.prototype.constructor = ScalaJS.c.rx_core_Var$;
ScalaJS.c.rx_core_Var$.prototype.apply__Lscala_Function0__T__Lrx_core_Var = (function(value, name) {
  return new ScalaJS.c.rx_core_Var().init___Lscala_Function0__T(value, name)
});
ScalaJS.c.rx_core_Var$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Var$.prototype.set__Lscala_collection_Seq__Lrx_core_Propagator__O = (function(thingies, evidence$3) {
  thingies.foreach__Lscala_Function1__V(new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(x$4) {
      x$4.commit__V();
      return ScalaJS.bV(undefined)
    })
  })()));
  return ScalaJS.modules.rx_core_Propagator().apply__Lrx_core_Propagator__Lrx_core_Propagator(evidence$3).propagate__Lscala_collection_immutable_Set__O(ScalaJS.as.scala_collection_TraversableOnce(thingies.flatMap__Lscala_Function1__Lscala_collection_generic_CanBuildFrom__O(new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(v) {
      return ScalaJS.as.scala_collection_immutable_Set(v.v__Lrx_core_Var().children__Lscala_collection_immutable_Set().map__Lscala_Function1__Lscala_collection_generic_CanBuildFrom__O(new ScalaJS.c.rx_core_Var$$anonfun$set$2$$anonfun$apply$1().init___Lrx_core_Var$$anonfun$set$2__Lrx_core_Staged(this, v), ScalaJS.modules.scala_collection_immutable_Set().canBuildFrom__Lscala_collection_generic_CanBuildFrom()))
    })
  })()), ScalaJS.modules.scala_collection_Seq().canBuildFrom__Lscala_collection_generic_CanBuildFrom())).toSet__Lscala_collection_immutable_Set())
});
ScalaJS.c.rx_core_Var$.prototype.$$lessinit$greater$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Var$.prototype.apply$default$2__ = (function() {
  return this.apply$default$2__T()
});
ScalaJS.c.rx_core_Var$.prototype.$$lessinit$greater$default$2__ = (function() {
  return this.$$lessinit$greater$default$2__T()
});
ScalaJS.c.rx_core_Var$.prototype.set__Lscala_collection_Seq__Lrx_core_Propagator__ = (function(thingies, evidence$3) {
  return this.set__Lscala_collection_Seq__Lrx_core_Propagator__O(thingies, evidence$3)
});
ScalaJS.c.rx_core_Var$.prototype.apply__Lscala_Function0__T__ = (function(value, name) {
  return this.apply__Lscala_Function0__T__Lrx_core_Var(value, name)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Var$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Var$.prototype = ScalaJS.c.rx_core_Var$.prototype;
ScalaJS.is.rx_core_Var$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Var$)))
});
ScalaJS.as.rx_core_Var$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Var$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Var")
  }
});
ScalaJS.isArrayOf.rx_core_Var$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Var$)))
});
ScalaJS.asArrayOf.rx_core_Var$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Var$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Var;", depth)
  }
});
ScalaJS.data.rx_core_Var$ = new ScalaJS.ClassTypeData({
  rx_core_Var$: 0
}, false, "rx.core.Var$", ScalaJS.data.java_lang_Object, {
  rx_core_Var$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Var$.prototype.$classData = ScalaJS.data.rx_core_Var$;
ScalaJS.moduleInstances.rx_core_Var = undefined;
ScalaJS.modules.rx_core_Var = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Var)) {
    ScalaJS.moduleInstances.rx_core_Var = new ScalaJS.c.rx_core_Var$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Var
});
//@ sourceMappingURL=Var$.js.map
